@@ -169,6 +169,12 @@ class LMDirect(Connection):
             None,
         )
 
+    def _get_key(self, k):
+        """Construct tag name if needed."""
+        if isinstance(k, tuple):
+            k = "_".join(k)
+        return k
+
     """Services"""
 
     async def set_power(self, power):
@@ -210,7 +216,7 @@ class LMDirect(Connection):
 
             """Update the stored values to immediately reflect the change"""
             for state in [self._temp_state, self._current_status]:
-                state[day_of_week] = ENABLED if enable else DISABLED
+                state[self._get_key((day_of_week, AUTO))] = ENABLED if enable else DISABLED
                 state[AUTO_BITFIELD] = bitfield
 
             self._call_callbacks(entity_type=TYPE_AUTO_ON_OFF)
@@ -390,7 +396,7 @@ class LMDirect(Connection):
 
             """Validate input."""
             if not (
-                0 <= seconds <= 5.9 and 1 <= key <= 4
+                0 <= seconds <= 24.9 and 1 <= key <= 4
             ):
                 raise InvalidInput(f"Invalid values {seconds=}")
 
